# formatprint
An easy-to-use package for custom formatted printing, allowing you to pretty-print complex data structures with color and style options.

## Installation

```bash
pip install balboniprint
```


